==> fabcoin-1.0.8.tgz: package/rpcapi.js <==
//Implementing all http get method by express on seprate business module like...
// Call test method from rpc that wants to has called by post method
//
var express = require('express'),
  parseurl = require('parseurl'),
  session = require('express-session'),
  uuid = require('uuid');

var tmpresult = function() {
  var tmprouter = express.Router();
  var tmprpcagent = require('./rcpagent')()
  var tmprealtimemodule = require('./realtimemodule')(global.client);
  var requestTime = (function(req, res, next) {
    req.requestTime = Date.now();
    //console.log(req.requestTime);
    next();
  });
  var modulelogger = (function(req, res, next) {
    //console.log(res)
    next()
  });
  var currentnode = (function(req, res, next) {
    global.client.getAddedNodeInfo(function(pex, pinfo) {
      if (pex) {
        res.json(pex);
      }
      //console.log(pinfo);
      req.currentnode = pinfo;
      next();
    });
  });
  tmprouter.use(modulelogger);
  tmprouter.use(requestTime);
  //tmprouter.use(session({secret: {ip:'127.0.0.1',port:'20834',user:'nader',pass:'654'},  resave: false,  saveUninitialized: true}));
  //tmprouter.use(currentnode);
  tmprouter.route('/getaddednodeinfo1')
    .post(function(req, res) {
      req.body.LastName = "Shah";
      res.send(req.body);
    });
  tmprouter.route('/addnode/:Ip/:Port')
    .get(tmprpcagent.addnode);
  tmprouter.route('/getinfo/:Id/:Pid')
    .get(function(req, res) {
      var tmpjson = {
        firstname: req.params.Id,
        lastname: req.params.Pid,
        time: req.requestTime
      };
      res.send(tmpjson);
    });
  tmprouter.use(session({
    secret: uuid(), //'Q3UBzdH9GEfiRCTKbi5MTPyChpzXLsTD',
    resave: false,
    saveUninitialized: true
  }))
  tmprouter.use(function(req, res, next) {
    if (!req.session.currentprofile) {
      req.session.views = {};
      var tmpjson = JSON.stringify(global.client);
      req.session.currentprofile = {};
      //console.log(tmpjson);
      var tmpinterfacejson = JSON.parse(tmpjson);
      tmpjson = {
        ip: tmpinterfacejson.rpc.opts.host,
        port: tmpinterfacejson.rpc.opts.port,
        login: tmpinterfacejson.rpc.opts.user,
        pwd: tmpinterfacejson.rpc.opts.pass
      };
      req.session.currentprofile[0] = tmpjson;
    }
    //console.log(tmpjson);
    var pathname = parseurl(req).pathname;
    req.session.views[pathname] = (req.session.views[pathname] || 0) + 1;
    next();
  })
  tmprouter.route('/page1')
    .get(function(req, res, next) {
      res.send('you viewed this page ' + req.session.views['/page1'] + ' times');
    });
  tmprouter.route('/page2')
    .get(function(req, res, next) {
      console.log(req.session);
      res.send('you viewed this page ' + req.session.views['/page2'] + ' times');
    });
  tmprouter.route('/nodeswitch')
    .post(tmprpcagent.nodeswitch);
  tmprouter.route('/nodesetting/:Ip/:Port')
    .get(function(req, res, next) {
      var tmpjson = {
        ip: req.params.Ip,
        port: req.params.Port
      };
      var tmpclientjson = req.session.currentprofile[0];
      res.send(tmpclientjson);
    });
  tmprouter.route('/currentprofile')
    .get(function(req, res, next) {
      console.log(global.client);
      var tmpjson = {
        ip: req.session.currentprofile[0].ip,
        port: req.session.currentprofile[0].port,
        login: req.session.currentprofile[0].login,
        pwd: '*****'
      };
      res.send(tmpjson); //express.session.views.length);
    });
  tmprouter.route('/walletpassphrasechange/:currentpassphrase/:newpassphrase')
    .get(tmprpcagent.walletpassphrasechange)
  tmprouter.route('/walletpassphrase/:passphrase/:seconds')
    .get(tmprpcagent.walletpassphrase)
  tmprouter.route('/walletlock')
    .get(tmprpcagent.walletlock)
  tmprouter.route('/verifytxoutproof')
    .post(tmprpcagent.verifytxoutproof)
  tmprouter.route('/verifymessage')
    .post(tmprpcagent.verifymessage)
  tmprouter.route('/verifychain/:checklevel?/:blocknumber?')
    .get(tmprpcagent.verifychain)
  tmprouter.route('/validateaddress/:address')
    .get(tmprpcagent.validateaddress)
  tmprouter.route('/submitblock')
    .post(tmprpcagent.submitblock)
  tmprouter.route('/stop')
    .get(tmprpcagent.stop)
  tmprouter.route('/signrawtransaction')
    .post(tmprpcagent.signrawtransaction)
  tmprouter.route('/signmessage/:address/:message')
    .get(tmprpcagent.signmessage)
  tmprouter.route('/settxfee/:transactionfee')
    .get(tmprpcagent.settxfee)
  tmprouter.route('/setgenerate/:activate')
    .get(tmprpcagent.setgenerate)
  tmprouter.route('/setaccount')
    .post(tmprpcagent.setaccount)
  tmprouter.route('/sendtoaddress')
    .post(tmprpcagent.sendtoaddress)
  tmprouter.route('/sendrawtransaction/:txid')
    .get(tmprpcagent.sendrawtransaction)
  tmprouter.route('/sendmany')
    .post(tmprpcagent.sendmany)
  tmprouter.route('/sendfrom')
    .post(tmprpcagent.sendfrom)
  tmprouter.route('/prioritisetransaction/:txid/:priority/:fee')
    .get(tmprpcagent.prioritisetransaction)
  tmprouter.route('/ping')
    .get(tmprpcagent.ping)
  //if you need I can wrapp by post type, but get is fastet
  tmprouter.route('/move/:fromaccount/:toaccount/:amount/:unused?/:comment?')
    .get(tmprpcagent.move)
  tmprouter.route('/lockunspent/:unlock')
    .get(tmprpcagent.lockunspent)
  tmprouter.route('/listunspent')
    .post(tmprpcagent.listunspent)
  tmprouter.route('/keypoolrefill/:keypoolsize')
    .get(tmprpcagent.keypoolrefill)
  tmprouter.route('/importwallet/:filename')
    .get(tmprpcagent.importwallet)
  tmprouter.route('/importwalletfile')
    .post(tmprpcagent.importwalletfile)
  tmprouter.route('/importprivkey/:privatekey/:account/:rescan')
    .get(tmprpcagent.importprivkey)
  tmprouter.route('/gettxoutproof')
    .post(tmprpcagent.gettxoutproof)
  tmprouter.route('/gettxout/:txid/:vout/:confirmationnumber')
    .get(tmprpcagent.gettxout)
  tmprouter.route('/getreceivedbyaddress/:address/:confirmationnumber')
    .get(tmprpcagent.getreceivedbyaddress)
  tmprouter.route('/getreceivedbyaccount/:account/:confirmationnumber')
    .get(tmprpcagent.getreceivedbyaccount)
  tmprouter.route('/gettransaction/:txid')
    .get(tmprpcagent.gettransaction)
  tmprouter.route('/getrawtransaction/:txid/:format')
    .get(tmprpcagent.getrawtransaction)
  tmprouter.route('/getrawchangeaddress')
    .get(tmprpcagent.getrawchangeaddress)
  tmprouter.route('/getnewaddress')
    .get(tmprpcagent.getnewaddress)
  tmprouter.route('/getnetworkhashps')
    .get(tmprpcagent.getnetworkhashps)
  tmprouter.route('/getnetworkinfo')
    .get(tmprpcagent.getnetworkinfo)
  tmprouter.route('/getnettotals')
    .get(tmprpcagent.getnettotals)
  tmprouter.route('/getmempoolinfo')
    .get(tmprpcagent.getmempoolinfo)
  tmprouter.route('/getchaintips')
    .get(tmprpcagent.getchaintips)
  tmprouter.route('/getblock/:headerhash/:format?')
    .post(tmprpcagent.getblock);
  tmprouter.route('/getblocktemplate')
    .post(tmprpcagent.getblocktemplate);
  tmprouter.route('/getblockhash/:blockheight')
    .get(tmprpcagent.getblockhash);
  tmprouter.route('/getwalletinfo')
    .get(tmprpcagent.getwalletinfo);
  tmprouter.route('/getinfo')
    .get(tmprpcagent.getinfo);
  tmprouter.route('/getaddednodeinfo')
    .get(tmprpcagent.getaddednodeinfo);
  tmprouter.route('/getdifficulty')
    .get(tmprpcagent.getdifficulty)
  tmprouter.route('/getblockcount')
    .get(tmprpcagent.getblockcount)
  tmprouter.route('/getblockchaininfo')
    .get(tmprpcagent.getblockchaininfo)
  tmprouter.route('/dumpwallet')
    .post(tmprpcagent.dumpwallet)
  tmprouter.route('/estimatepriority/:blocks')
    .get(tmprpcagent.estimatepriority)
  tmprouter.route('/encryptwallet/:passphrase')
    .get(tmprpcagent.encryptwallet)
  tmprouter.route('/dumpprivkey/:address')
    .get(tmprpcagent.dumpprivkey)
  tmprouter.route('/decodescript/:redeemscript')
    .get(tmprpcagent.decodescript)
  tmprouter.route('/decoderawtransaction/:serializedtransaction')
    .get(tmprpcagent.decoderawtransaction)
  tmprouter.route('/createrawtransaction')
    .post(tmprpcagent.createrawtransaction)
  tmprouter.route('/createmultisig')
    .post(tmprpcagent.createmultisig)
  tmprouter.route('/walletdownload')
    .get(tmprpcagent.walletdownload)
  tmprouter.route('/walletdownload')
    .get(tmprpcagent.walletdownload)
  tmprouter.route('/abandontransaction/:txid')
    .get(tmprpcagent.abandontransaction)
  tmprouter.route('/listlockunspent')
    .get(tmprpcagent.listlockunspent)
  tmprouter.route('/backupwallet')
    .get(tmprpcagent.backupwallet)
  tmprouter.route('/AddMultiSigAddress')
    .post(tmprpcagent.addmultisigaddress)
  tmprouter.route('/listaccounts/:confirmation/:watchonly?')
    .get(tmprpcagent.listaccounts)
  tmprouter.route('/getbalance/:account')
    .get(tmprpcagent.getbalance)
  tmprouter.route('/getaccountaddress/:account')
    .get(tmprpcagent.getaccountaddress)
  tmprouter.route('/getgenerate')
    .get(tmprpcagent.getgenerate)
  tmprouter.route('/generate/:blocks/:maxtries?')
    .get(tmprpcagent.generate)
  tmprouter.route('/getmininginfo')
    .get(tmprpcagent.getmininginfo)
  tmprouter.route('/getbestblockhash')
    .get(tmprpcagent.getbestblockhash)
  tmprouter.route('/getconnectioncount')
    .get(tmprpcagent.getconnectioncount)
  tmprouter.route('/getpeerinfo')
    .get(tmprpcagent.getpeerinfo)
  tmprouter.route('/getrawmempool')
    .get(tmprpcagent.getrawmempool)
  tmprouter.route('/gettxoutsetinfo')
    .get(tmprpcagent.gettxoutsetinfo)
  tmprouter.route('/gettxoutsetinfo1')
  //Should check with rpc back-seource
  //--Error, It works fine with Curl and in there result is null, I couldn't find method
  //It's removed
  tmprouter.route('/gethashespersec')
    .get(tmprpcagent.gethashespersec)
  //getblocknumber--Error, It works fine with Curl and in there result is null,I couldn't find method
  //It's removed
  tmprouter.route('/getblocknumber')
    .get(tmprpcagent.getblocknumber)
  tmprouter.route('/getunconfirmedbalance')
    .get(tmprpcagent.getunconfirmedbalance)
  tmprouter.route('/help')
    .get(tmprpcagent.help)
  tmprouter.route('/importaddress/:address/:account/:rescan')
    .get(tmprpcagent.importaddress)
  tmprouter.route('/getaccount/:address')
    .get(tmprpcagent.getaccount)
  tmprouter.route('/listreceivedbyaccount/:confirmation?/:includeempty?/:watchOnly?')
    .get(tmprpcagent.listreceivedbyaccount)
  tmprouter.route('/listreceivedbyaddress/:confirmation?/:includeempty?/:watchOnly?')
    .get(tmprpcagent.listreceivedbyaddress)
  tmprouter.route('/listsinceblock/:headerhash?/:targetconfirmations?/:watchOnly?')
    .get(tmprpcagent.listsinceblock)
  tmprouter.route('/listtransactions/:account?/:count?/:skip?/:watchOnly?')
    .get(tmprpcagent.listtransactions)
  tmprouter.route('/dictionary')
    .get(tmprpcagent.index)
  return tmprouter;
}
module.exports.rpcapi = tmpresult;

==> fabcoin-1.0.11.tgz: package/rpcapi.js <==
//Implementing all http get method by express on seprate business module like...
// Call test method from rpc that wants to has called by post method
//
var express = require('express'),
  parseurl = require('parseurl'),
  session = require('express-session'),
  uuid = require('uuid');

var tmpresult = function() {
  var tmprouter = express.Router();
  var tmprpcagent = require('./rcpagent')()
  //var tmprealtimemodule = require('./realtimemodule')(global.client);
  var requestTime = (function(req, res, next) {
    req.requestTime = Date.now();
    //console.log(req.requestTime);
    next();
  });
  var modulelogger = (function(req, res, next) {
    //console.log(res)
    next()
  });
  var currentnode = (function(req, res, next) {
    global.client.getAddedNodeInfo(function(pex, pinfo) {
      if (pex) {
        res.json(pex);
      }
      //console.log(pinfo);
      req.currentnode = pinfo;
      next();
    });
  });
  tmprouter.use(modulelogger);
  tmprouter.use(requestTime);
  //tmprouter.use(session({secret: {ip:'127.0.0.1',port:'20834',user:'nader',pass:'654'},  resave: false,  saveUninitialized: true}));
  //tmprouter.use(currentnode);
  tmprouter.route('/getaddednodeinfo1')
    .post(function(req, res) {
      req.body.LastName = "Shah";
      res.send(req.body);
    });
  tmprouter.route('/addnode/:Ip/:Port')
    .get(tmprpcagent.addnode);
  tmprouter.route('/getinfo/:Id/:Pid')
    .get(function(req, res) {
      var tmpjson = {
        firstname: req.params.Id,
        lastname: req.params.Pid,
        time: req.requestTime
      };
      res.send(tmpjson);
    });
  tmprouter.use(session({
    secret: uuid(), //'Q3UBzdH9GEfiRCTKbi5MTPyChpzXLsTD',
    resave: false,
    saveUninitialized: true
  }))
  tmprouter.use(function(req, res, next) {
    if (!req.session.currentprofile) {
      req.session.views = {};
      var tmpjson = JSON.stringify(global.client);
      req.session.currentprofile = {};
      //console.log(tmpjson);
      var tmpinterfacejson = JSON.parse(tmpjson);
      tmpjson = {
        ip: tmpinterfacejson.rpc.opts.host,
        port: tmpinterfacejson.rpc.opts.port,
        login: tmpinterfacejson.rpc.opts.user,
        pwd: tmpinterfacejson.rpc.opts.pass
      };
      req.session.currentprofile[0] = tmpjson;
    }
    //console.log(tmpjson);
    var pathname = parseurl(req).pathname;
    req.session.views[pathname] = (req.session.views[pathname] || 0) + 1;
    next();
  })
  tmprouter.route('/page1')
    .get(function(req, res, next) {
      res.send('you viewed this page ' + req.session.views['/page1'] + ' times');
    });
  tmprouter.route('/page2')
    .get(function(req, res, next) {
      console.log(req.session);
      res.send('you viewed this page ' + req.session.views['/page2'] + ' times');
    });
  tmprouter.route('/nodeswitch')
    .post(tmprpcagent.nodeswitch);
  tmprouter.route('/nodesetting/:Ip/:Port')
    .get(function(req, res, next) {
      var tmpjson = {
        ip: req.params.Ip,
        port: req.params.Port
      };
      var tmpclientjson = req.session.currentprofile[0];
      res.send(tmpclientjson);
    });
  tmprouter.route('/currentprofile')
    .get(function(req, res, next) {
      console.log(global.client);
      var tmpjson = {
        ip: req.session.currentprofile[0].ip,
        port: req.session.currentprofile[0].port,
        login: req.session.currentprofile[0].login,
        pwd: '*****'
      };
      res.send(tmpjson); //express.session.views.length);
    });
  tmprouter.route('/walletpassphrasechange/:currentpassphrase/:newpassphrase')
    .get(tmprpcagent.walletpassphrasechange)
  tmprouter.route('/walletpassphrase/:passphrase/:seconds')
    .get(tmprpcagent.walletpassphrase)
  tmprouter.route('/walletlock')
    .get(tmprpcagent.walletlock)
  tmprouter.route('/verifytxoutproof')
    .post(tmprpcagent.verifytxoutproof)
  tmprouter.route('/verifymessage')
    .post(tmprpcagent.verifymessage)
  tmprouter.route('/verifychain/:checklevel?/:blocknumber?')
    .get(tmprpcagent.verifychain)
  tmprouter.route('/validateaddress/:address')
    .get(tmprpcagent.validateaddress)
  tmprouter.route('/submitblock')
    .post(tmprpcagent.submitblock)
  tmprouter.route('/stop')
    .get(tmprpcagent.stop)
  tmprouter.route('/signrawtransaction')
    .post(tmprpcagent.signrawtransaction)
  tmprouter.route('/signmessage/:address/:message')
    .get(tmprpcagent.signmessage)
  tmprouter.route('/settxfee/:transactionfee')
    .get(tmprpcagent.settxfee)
  tmprouter.route('/setgenerate/:activate')
    .get(tmprpcagent.setgenerate)
  tmprouter.route('/setaccount')
    .post(tmprpcagent.setaccount)
  tmprouter.route('/sendtoaddress')
    .post(tmprpcagent.sendtoaddress)
  tmprouter.route('/sendrawtransaction/:txid')
    .get(tmprpcagent.sendrawtransaction)
  tmprouter.route('/sendmany')
    .post(tmprpcagent.sendmany)
  tmprouter.route('/sendfrom')
    .post(tmprpcagent.sendfrom)
  tmprouter.route('/prioritisetransaction/:txid/:priority/:fee')
    .get(tmprpcagent.prioritisetransaction)
  tmprouter.route('/ping')
    .get(tmprpcagent.ping)
  //if you need I can wrapp by post type, but get is fastet
  tmprouter.route('/move/:fromaccount/:toaccount/:amount/:unused?/:comment?')
    .get(tmprpcagent.move)
  tmprouter.route('/lockunspent/:unlock')
    .get(tmprpcagent.lockunspent)
  tmprouter.route('/listunspent')
    .post(tmprpcagent.listunspent)
  tmprouter.route('/keypoolrefill/:keypoolsize')
    .get(tmprpcagent.keypoolrefill)
  tmprouter.route('/importwallet/:filename')
    .get(tmprpcagent.importwallet)
  tmprouter.route('/importwalletfile')
    .post(tmprpcagent.importwalletfile)
  tmprouter.route('/importprivkey/:privatekey/:account/:rescan')
    .get(tmprpcagent.importprivkey)
  tmprouter.route('/gettxoutproof')
    .post(tmprpcagent.gettxoutproof)
  tmprouter.route('/gettxout/:txid/:vout/:confirmationnumber')
    .get(tmprpcagent.gettxout)
  tmprouter.route('/getreceivedbyaddress/:address/:confirmationnumber')
    .get(tmprpcagent.getreceivedbyaddress)
  tmprouter.route('/getreceivedbyaccount/:account/:confirmationnumber')
    .get(tmprpcagent.getreceivedbyaccount)
  tmprouter.route('/gettransaction/:txid')
    .get(tmprpcagent.gettransaction)
  tmprouter.route('/getrawtransaction/:txid/:format')
    .get(tmprpcagent.getrawtransaction)
  tmprouter.route('/getrawchangeaddress')
    .get(tmprpcagent.getrawchangeaddress)
  tmprouter.route('/getnewaddress')
    .get(tmprpcagent.getnewaddress)
  tmprouter.route('/getnetworkhashps')
    .get(tmprpcagent.getnetworkhashps)
  tmprouter.route('/getnetworkinfo')
    .get(tmprpcagent.getnetworkinfo)
  tmprouter.route('/getnettotals')
    .get(tmprpcagent.getnettotals)
  tmprouter.route('/getmempoolinfo')
    .get(tmprpcagent.getmempoolinfo)
  tmprouter.route('/getchaintips')
    .get(tmprpcagent.getchaintips)
  tmprouter.route('/getblock/:headerhash/:format?')
    .post(tmprpcagent.getblock);
  tmprouter.route('/getblocktemplate')
    .post(tmprpcagent.getblocktemplate);
  tmprouter.route('/getblockhash/:blockheight')
    .get(tmprpcagent.getblockhash);
  tmprouter.route('/getwalletinfo')
    .get(tmprpcagent.getwalletinfo);
  tmprouter.route('/getinfo')
    .get(tmprpcagent.getinfo);
  tmprouter.route('/getaddednodeinfo')
    .get(tmprpcagent.getaddednodeinfo);
  tmprouter.route('/getdifficulty')
    .get(tmprpcagent.getdifficulty)
  tmprouter.route('/getblockcount')
    .get(tmprpcagent.getblockcount)
  tmprouter.route('/getblockchaininfo')
    .get(tmprpcagent.getblockchaininfo)
  tmprouter.route('/dumpwallet')
    .post(tmprpcagent.dumpwallet)
  tmprouter.route('/estimatepriority/:blocks')
    .get(tmprpcagent.estimatepriority)
  tmprouter.route('/encryptwallet/:passphrase')
    .get(tmprpcagent.encryptwallet)
  tmprouter.route('/dumpprivkey/:address')
    .get(tmprpcagent.dumpprivkey)
  tmprouter.route('/decodescript/:redeemscript')
    .get(tmprpcagent.decodescript)
  tmprouter.route('/decoderawtransaction/:serializedtransaction')
    .get(tmprpcagent.decoderawtransaction)
  tmprouter.route('/createrawtransaction')
    .post(tmprpcagent.createrawtransaction)
  tmprouter.route('/createmultisig')
    .post(tmprpcagent.createmultisig)
  tmprouter.route('/walletdownload')
    .get(tmprpcagent.walletdownload)
  tmprouter.route('/walletdownload')
    .get(tmprpcagent.walletdownload)
  tmprouter.route('/abandontransaction/:txid')
    .get(tmprpcagent.abandontransaction)
  tmprouter.route('/listlockunspent')
    .get(tmprpcagent.listlockunspent)
  tmprouter.route('/backupwallet')
    .get(tmprpcagent.backupwallet)
  tmprouter.route('/AddMultiSigAddress')
    .post(tmprpcagent.addmultisigaddress)
  tmprouter.route('/listaccounts/:confirmation/:watchonly?')
    .get(tmprpcagent.listaccounts)
  tmprouter.route('/getbalance/:account')
    .get(tmprpcagent.getbalance)
  tmprouter.route('/getaccountaddress/:account')
    .get(tmprpcagent.getaccountaddress)
  tmprouter.route('/getgenerate')
    .get(tmprpcagent.getgenerate)
  tmprouter.route('/generate/:blocks/:maxtries?')
    .get(tmprpcagent.generate)
  tmprouter.route('/getmininginfo')
    .get(tmprpcagent.getmininginfo)
  tmprouter.route('/getbestblockhash')
    .get(tmprpcagent.getbestblockhash)
  tmprouter.route('/getconnectioncount')
    .get(tmprpcagent.getconnectioncount)
  tmprouter.route('/getpeerinfo')
    .get(tmprpcagent.getpeerinfo)
  tmprouter.route('/getrawmempool')
    .get(tmprpcagent.getrawmempool)
  tmprouter.route('/gettxoutsetinfo')
    .get(tmprpcagent.gettxoutsetinfo)
  tmprouter.route('/gettxoutsetinfo1')
  //Should check with rpc back-seource
  //--Error, It works fine with Curl and in there result is null, I couldn't find method
  //It's removed
  tmprouter.route('/gethashespersec')
    .get(tmprpcagent.gethashespersec)
  //getblocknumber--Error, It works fine with Curl and in there result is null,I couldn't find method
  //It's removed
  tmprouter.route('/getblocknumber')
    .get(tmprpcagent.getblocknumber)
  tmprouter.route('/getunconfirmedbalance')
    .get(tmprpcagent.getunconfirmedbalance)
  tmprouter.route('/help')
    .get(tmprpcagent.help)
  tmprouter.route('/importaddress/:address/:account/:rescan')
    .get(tmprpcagent.importaddress)
  tmprouter.route('/getaccount/:address')
    .get(tmprpcagent.getaccount)
  tmprouter.route('/listreceivedbyaccount/:confirmation?/:includeempty?/:watchOnly?')
    .get(tmprpcagent.listreceivedbyaccount)
  tmprouter.route('/listreceivedbyaddress/:confirmation?/:includeempty?/:watchOnly?')
    .get(tmprpcagent.listreceivedbyaddress)
  tmprouter.route('/listsinceblock/:headerhash?/:targetconfirmations?/:watchOnly?')
    .get(tmprpcagent.listsinceblock)
  tmprouter.route('/listtransactions/:account?/:count?/:skip?/:watchOnly?')
    .get(tmprpcagent.listtransactions)
  tmprouter.route('/dictionary')
    .get(tmprpcagent.index)
  tmprouter.route('/test')
  .get(function(req, res) {
    var tmpjson = {
      "message": "you don't have bug in rpc calling"
    };
    res.send(tmpjson);
  });
  return tmprouter;
}
module.exports = tmpresult;
